==> react-native-web-jsonschema-form-1.0.28.tgz: package/fields/StringField.js <==
import _without from "lodash/without";
import _isArray from "lodash/isArray";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { StyleSheet } from 'react-native';
import AbstractField from './AbstractField';
const styles = StyleSheet.create({
  padding: {
    paddingLeft: 10
  }
});
const password = /password$/i;
const email = /(email|username)$/i;
const phone = /(phone|mobile|cellphone)$/i;
const message = /(message|text|notes)$/i;
const zip = /zip$/i;

class StringField extends AbstractField {
  getDefaultWidget() {
    const {
      name,
      widgets,
      schema
    } = this.props;
    let Widget;

    if (schema.format === 'date-time') {
      Widget = widgets.DateWidget;
    } else if (password.test(name)) {
      Widget = widgets.PasswordWidget;
    } else if (email.test(name)) {
      Widget = widgets.EmailWidget;
    } else if (phone.test(name)) {
      Widget = widgets.PhoneWidget;
    } else if (message.test(name)) {
      Widget = widgets.TextareaWidget;
    } else if (zip.test(name)) {
      Widget = widgets.ZipWidget;
    } else {
      Widget = widgets.TextInputWidget;
    }

    return Widget;
  }

  getWidget() {
    const {
      schema,
      widgets,
      uiSchema
    } = this.props;
    let Widget;
    const widgetName = uiSchema['ui:widget'];

    if (widgetName === 'radioboxes' || widgetName === 'checkboxes') {
      let values = uiSchema['ui:enum'] || schema.enum || [];

      if (_isArray(uiSchema['ui:enumExcludes'])) {
        values = _without(values, uiSchema['ui:enumExcludes']);
      }

      const labels = uiSchema['ui:enumNames'] || schema.enumNames || values;
      const {
        RadioWidget,
        CheckboxWidget
      } = widgets;
      const BaseWidget = widgetName === 'radio' ? RadioWidget : CheckboxWidget;

      Widget = ({
        value,
        style,
        ...props
      }) => React.createElement(React.Fragment, null, values.map((trueValue, i) => React.createElement(BaseWidget, _extends({}, props, {
        key: trueValue,
        text: labels[i],
        checked: value === trueValue,
        style: [uiSchema['ui:inline'] && (i > 0 || uiSchema['ui:title'] !== false) ? styles.padding : null, style],
        value: trueValue
      }))));
    }

    return Widget;
  }

}

export default StringField;

==> react-native-web-jsonschema-form-1.1.1.tgz: package/fields/StringField.js <==
import _without from "lodash/without";
import _isArray from "lodash/isArray";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { StyleSheet } from 'react-native';
import AbstractField from './AbstractField';
const styles = StyleSheet.create({
  padding: {
    paddingLeft: 10
  }
});
const password = /password$/i;
const email = /(email|username)$/i;
const phone = /(phone|mobile|cellphone)$/i;
const message = /(message|text|notes)$/i;
const zip = /zip$/i;

class StringField extends AbstractField {
  getDefaultWidget() {
    const {
      name,
      widgets,
      schema
    } = this.props;
    let Widget;

    if (schema.format === 'date-time') {
      Widget = widgets.DateWidget;
    } else if (password.test(name)) {
      Widget = widgets.PasswordWidget;
    } else if (email.test(name)) {
      Widget = widgets.EmailWidget;
    } else if (phone.test(name)) {
      Widget = widgets.PhoneWidget;
    } else if (message.test(name)) {
      Widget = widgets.TextareaWidget;
    } else if (zip.test(name)) {
      Widget = widgets.ZipWidget;
    } else {
      Widget = widgets.TextInputWidget;
    }

    return Widget;
  }

  getWidget() {
    const {
      schema,
      widgets,
      uiSchema
    } = this.props;
    let Widget;
    const widgetName = uiSchema['ui:widget'];

    if (widgetName === 'radioboxes' || widgetName === 'checkboxes') {
      let values = uiSchema['ui:enum'] || schema.enum || [];

      if (_isArray(uiSchema['ui:enumExcludes'])) {
        values = _without(values, uiSchema['ui:enumExcludes']);
      }

      const labels = uiSchema['ui:enumNames'] || schema.enumNames || values;
      const {
        RadioWidget,
        CheckboxWidget
      } = widgets;
      const BaseWidget = widgetName === 'radioboxes' ? RadioWidget : CheckboxWidget;

      Widget = ({
        value,
        style,
        ...props
      }) => React.createElement(React.Fragment, null, values.map((trueValue, i) => React.createElement(BaseWidget, _extends({}, props, {
        key: trueValue,
        text: labels[i],
        checked: value === trueValue,
        style: [uiSchema['ui:inline'] && (i > 0 || uiSchema['ui:title'] !== false) ? styles.padding : null, style],
        value: trueValue
      }))));
    }

    return Widget;
  }

}

export default StringField;
